Composite Datasets
==================

.. automodule:: pyvista.composite
   :show-inheritance:

MultiBlock Datasets
-------------------

.. rubric:: Attributes

.. autoautosummary:: pyvista.MultiBlock
   :attributes:

.. rubric:: Methods

.. autoautosummary:: pyvista.MultiBlock
   :methods:


.. autoclass:: pyvista.MultiBlock
   :show-inheritance:
   :members:
   :undoc-members:
